@@ -434,7 +434,9 @@ class MainWindow(QtWidgets.QMainWindow):
             enabled=False,
         )
         crossHair = action(self.tr('&Toggle cross hair(+)'), self.crossHairToggle,
-                tip=self.tr('Show cross hair around the mouse cursor'), checkable=True, checked=self._config['cross_hair'],)
+                           shortcuts['cross_hair'], 'cross_hair',
+                           tip=self.tr('Show cross hair around the mouse cursor'),
+                           checkable=True, checked=self._config['cross_hair'],)
         crossHair.setChecked(self._config['cross_hair'])
         darkMode = action(self.tr('&Toggle dark theme'), self.darkModeToggle,
                 tip=self.tr('Toggle dark theme'), checkable=True, checked=self._config['dark_mode'],)
@@ -558,7 +560,8 @@ class MainWindow(QtWidgets.QMainWindow):
             edit=self.menu(self.tr('&Edit')),
             view=self.menu(self.tr('&View')),
             help=self.menu(self.tr('&Help')),
-            recentFiles=QtWidgets.QMenu(self.tr('Open &Recent')),
+            recentFiles=QtWidgets.QMenu(self.tr('Open &Recent File')),
+            recentDirectories=QtWidgets.QMenu(self.tr('Open &Recent Directory')),
             labelList=labelMenu,
         )
 
@@ -570,6 +573,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 openPrevImg,
                 opendir,
                 self.menus.recentFiles,
+                self.menus.recentDirectories,
                 save,
                 saveAs,
                 saveAuto,
@@ -579,6 +583,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 deleteFile,
                 None,
                 prefer,
+                None,
                 quit,
             ),
         )
@@ -612,6 +617,7 @@ class MainWindow(QtWidgets.QMainWindow):
         )
 
         self.menus.file.aboutToShow.connect(self.updateFileMenu)
+        #self.menus.file.aboutToShow.connect(self.updateDirectoryMenu)
 
         # Custom context menu for the canvas widget:
         utils.addActions(self.canvas.menus[0], self.actions.menu)
@@ -660,7 +666,8 @@ class MainWindow(QtWidgets.QMainWindow):
         self.image = QtGui.QImage()
         self.imagePath = None
         self.recentFiles = []
-        self.maxRecent = 7
+        self.recentDirectories = []
+        self.maxRecent = 10
         self.otherData = None
         self.zoom_level = 100
         self.fit_window = False
@@ -685,6 +692,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.settings = QtCore.QSettings('enhancedlabelme', 'enhancedlabelme')
         # FIXME: QSettings.value can return None on PyQt4
         self.recentFiles = self.settings.value('recentFiles', []) or []
+        self.recentDirectories = self.settings.value('recentDirectories', []) or []
         size = self.settings.value('window/size', QtCore.QSize(600, 500))
         position = self.settings.value('window/position', QtCore.QPoint(0, 0))
         self.resize(size)
@@ -696,6 +704,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         # Populate the File menu dynamically.
         self.updateFileMenu()
+        self.updateDirectoryMenu()
         # Since loading the file may take some time,
         # make sure it runs in the background.
         if self.filename is not None:
@@ -825,6 +834,13 @@ class MainWindow(QtWidgets.QMainWindow):
         elif len(self.recentFiles) >= self.maxRecent:
             self.recentFiles.pop()
         self.recentFiles.insert(0, filename)
+        
+    def addRecentDirectory(self, dirpath):
+        if dirpath in self.recentDirectories:
+            self.recentDirectories.remove(dirpath)
+        elif len(self.recentDirectories) >= self.maxRecent:
+            self.recentDirectories.pop()
+        self.recentDirectories.insert(0, dirpath)
 
     # Callbacks
 
@@ -955,6 +971,25 @@ class MainWindow(QtWidgets.QMainWindow):
                 icon, '&%d %s' % (i + 1, QtCore.QFileInfo(f).fileName()), self)
             action.triggered.connect(functools.partial(self.loadRecent, f))
             menu.addAction(action)
+            
+    def updateDirectoryMenu(self):
+        try:
+            current = osp.dirname(self.filename)
+
+            def exists(filename):
+                return osp.exists(str(filename))
+
+            menu = self.menus.recentDirectories
+            menu.clear()
+            directories = [f for f in self.recentDirectories if f != current and exists(f)]
+            for i, f in enumerate(directories):
+                icon = utils.newIcon('labels')
+                action = QtWidgets.QAction(
+                    icon, '&%d %s' % (i + 1, current), self)
+                action.triggered.connect(functools.partial(self.loadRecentDirectory, f))
+                menu.addAction(action)
+        except Exception:
+            pass
 
     def popLabelListMenu(self, point):
         self.menus.labelList.exec_(self.labelList.mapToGlobal(point))
@@ -1550,6 +1585,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.settings.setValue('window/position', self.pos())
         self.settings.setValue('window/state', self.saveState())
         self.settings.setValue('recentFiles', self.recentFiles)
+        self.settings.setValue('recentDirectories', self.recentDirectories)
         # ask the use for where to save the labels
         # self.settings.setValue('window/geometry', self.saveGeometry())
         
@@ -1577,6 +1613,10 @@ class MainWindow(QtWidgets.QMainWindow):
     def loadRecent(self, filename):
         if self.mayContinue():
             self.loadFile(filename)
+            
+    def loadRecentDirectory(self,dirpath):
+        if self.mayContinue():
+            self.loadDir(dirpath)
 
     def openPrevImg(self, _value=False):
         keep_prev = self._config['keep_prev']
@@ -1737,13 +1777,16 @@ class MainWindow(QtWidgets.QMainWindow):
             self.setClean()
 
     def closeFile(self, _value=False):
-        if not self.mayContinue():
-            return
-        self.setClean()
-        self.resetState()
-        self.toggleActions(False)
-        self.canvas.setEnabled(False)
-        self.actions.saveAs.setEnabled(False)
+        try:
+            if not self.mayContinue():
+                return
+            self.setClean()
+            self.resetState()
+            self.toggleActions(False)
+            self.canvas.setEnabled(False)
+            self.actions.saveAs.setEnabled(False)
+        except Exception:
+            pass
 
     def getLabelFile(self):
         if self.filename.lower().endswith('.json'):
@@ -1862,6 +1905,13 @@ class MainWindow(QtWidgets.QMainWindow):
             QtWidgets.QFileDialog.ShowDirsOnly |
             QtWidgets.QFileDialog.DontResolveSymlinks))
         self.importDirImages(targetDirPath)
+        
+    def loadDir(self, dirpath):
+        if not self.mayContinue():
+            return
+        self.addRecentDirectory(dirpath)
+        self.importDirImages(dirpath)
+       
 
     @property
     def imageList(self):
