@@ -41,7 +41,7 @@ class Canvas(QtWidgets.QWidget):
         self.epsilon = kwargs.pop('epsilon', 10.0)
         self.double_click = kwargs.pop('double_click', 'None')
         self.cross_onoff = kwargs.pop('cross_hair')
-        print(self.cross_onoff)
+        self.cross_temp = 0
         if self.double_click not in [None, 'close']:
             raise ValueError(
                 'Unexpected value for double_click event: {}'
@@ -536,11 +536,17 @@ class Canvas(QtWidgets.QWidget):
         p.drawPixmap(0, 0, self.pixmap)
         Shape.scale = self.scale
         
-        if self.cross == True:
-            p.setPen(QtGui.QPen(QtCore.Qt.blue, 1, QtCore.Qt.DashLine))
-            p.drawLine(self.posc.x(), self.pixmap.height(), self.posc.x(), 0)
-            p.drawLine(0, self.posc.y(), self.pixmap.width(), self.posc.y())
-            self.update()
+        if self.cross_onoff == True and self.cross_temp == 0:
+            self.cross_temp = 1
+            self.cross = True
+        try:
+            if self.cross == True:
+                p.setPen(QtGui.QPen(QtCore.Qt.black, 0.7, QtCore.Qt.SolidLine))
+                p.drawLine(self.posc.x(), self.pixmap.height(), self.posc.x(), 0)
+                p.drawLine(0, self.posc.y(), self.pixmap.width(), self.posc.y())
+                self.update()
+        except Exception:
+            pass
 
         for shape in self.shapes:
             if (shape.selected or not self._hideBackround) and \
